@@ -18,13 +18,23 @@ class Validator(object):
         if 'output' not in params:
             params['output'] = self.DEFAULT_OUTPUT
 
-        resp = requests.post(uri, data=params, files=files, headers=headers)
-
+        try:
+            resp = requests.post(uri, data=params, files=files, headers=headers, timeout=1)
+        except requests.exceptions.Timeout:
+            resp = None
         self._process_response(resp)
 
     def _process_response(self, resp):
         self.errors = []
         self.warnings = []
+        if resp is None:
+            self.type = 'html'
+            self.content = '<p>Request to {} took longer than 1 second.<p>'.format(self.VALIDATOR_URL)
+            self.error_count = 0
+            self.warning_count = 0
+            self.status = 'Timeout'
+            return
+
         if 'json' in resp.headers['content-type']:
             self.type = 'json'
             self.content = resp.json()
@@ -32,7 +42,7 @@ class Validator(object):
             for message in self.content.get('messages', []):
                 if 'lastLine' in message:
                     i = message['lastLine']
-                    if hasattr(self, 'source'):
+                    if hasattr(self, 'source') and len(self.source) > i-1:
                         message['src'] = self.source[i-1]
                 if message['type'] == u'error':
                     self.errors.append(message)
